VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CFile"
Attribute VB_Creatable = False
Attribute VB_Exposed = False
Option Explicit
'******************************************************************************************
'** Copyright 1996 - SAMS Publishing
'**
'**   Microsoft SQL Server DBA Survival Guide
'**
'** Authors: Mark Spenik and Orryn Sledge
'**
'** Class: CFile
'** Description: The CFILE class performs simple File I/o with text files such
'**                       Open, Read and Close.
'**
'** Please read the software agreement that comes with the book.
'**
'**********************************************************************************************
'
Private miFileHandle As Integer             'Private File Handle
Private miStatus As Integer                     'Error Flag - True = OK, 2 = EOF and False = Error
Private msIOType As String                    'Type of I/O - Sequential, Binary etc. etc.
Private msIOMode As String                   ' Mode to Open the file - Input, Output, Append etc. etc.
Private msFileName As String                 'File Name
'
' Class Constants - (Note: All must be defined again in .BAS file as Public)
'
Private Const FILE_ERROR = 0
Private Const SUCCESS = 1
Private Const END_OF_FILE = 2
Private Const FILE_NOT_OPEN = 3
Public Sub OpenFile()
' OpenFile opens the file in the property FileName and sets the property value
' FileHandle for future File I/O.
'
    'Set up the error handler
    On Error GoTo Open_Error
    
    '
    ' Get a free file handle
    FileHandle = FreeFile
    
    '
    'Open the file in Sequential Mode - Later versions can be modified to handle other Access
    '                                                           types like Binary or Randomn
    '
    '
    Select Case IOType
        Case "SEQUENTIAL"
            'For Sequential Access - We have three possible modes Input, Output and Append
            Select Case IOMode
                Case "OUTPUT"
                    Open FileName For Output As #FileHandle
                Case "APPEND"
                    Open FileName For Append As #FileHandle
                Case Else     'Default Input
                    Open FileName For Input As #FileHandle
            End Select
        '
        'If not Sequential
        Case Else
            MsgBox "Only Sequential FILE I/O currently supported"
            GoTo Exit_Open
    End Select
    
    'Set the Status property to File Open for other methods
    Status = SUCCESS
Exit_Open:
    Exit Sub
    
'
'Error Handler
'
Open_Error:
    MsgBox "OpenFile()- Error opening file - " & FileName & " " _
        & Err.Description
    'Set the Status property to failure
    Status = FILE_NOT_OPEN
    Resume Exit_Open
End Sub
Public Sub CloseFile()
    '
    'Close the FileHandle and set to 0
    '
    Close #FileHandle
    FileHandle = 0 'Reset the file handle
    Status = FILE_NOT_OPEN 'Reset the Status
End Sub

Public Sub ReadAll(TextBuffer As String)
Dim OneLine As String
    
    '
    'Check for errors and exit if False
    If Status = FILE_NOT_OPEN Then GoTo Exit_Read
    
    '
    'Setup the error handler
    On Error GoTo Read_Error
    
    '
    'Read data into
    'the OneLine variable and
    'store in the TextBuffer
    'until the end of the File
    '
    While Not (EOF(FileHandle))
        Line Input #FileHandle, OneLine
        TextBuffer = TextBuffer + OneLine + Chr(13) + Chr(10)
    Wend
    Status = SUCCESS
Exit_Read:
    Exit Sub
    '
    ' Error Handler
    '
Read_Error:
    MsgBox "ReadAll()- Error reading file - " & FileName & " " _
        & Err.Description
    Status = FILE_ERROR  'Set the status property to error condition
    Resume Exit_Read

End Sub

Private Sub Class_Initialize()
    Status = FILE_NOT_OPEN
End Sub
Public Property Get FileName() As String
    'Get the value of the private member
    FileName = msFileName
End Property
Public Property Let FileName(sFileName As String)
    'Set the private file name parameter value
    msFileName = sFileName
End Property
Private Property Get FileHandle() As Integer
    'Get the file Handle value from the private variable
    FileHandle = miFileHandle
End Property
Private Property Let FileHandle(iFileHandle As Integer)
    'Set the File Handle Property
    miFileHandle = iFileHandle
End Property
Public Property Get Status() As Integer
    'Outside of the class - can only read the status - not set it
    Status = miStatus
End Property
Private Property Let Status(iStatus As Integer)
    miStatus = iStatus
End Property
Public Property Get IOType() As String
    'Return the IOType Value
    IOType = msIOType
End Property
Public Property Let IOType(sIOType As String)
    '
    'Validate the IOType being passed - default to Sequential
    '  Make all Uppercase - for comparrisons
    '
    sIOType = UCase(sIOType)
    
    If ((StrComp(sIOType, "BINARY") = 0) Or (StrComp(sIOType, "RANDOM") = 0)) Then
        msIOType = sIOType
    Else
        msIOType = "SEQUENTIAL"
    End If

End Property
Public Property Get IOMode() As String
    'Get the current IOMode of the private value
    IOMode = msIOMode
End Property
Public Property Let IOMode(sIOMode As String)
    'Validate - then set the value
    '   Default to INPUT
    '
    sIOMode = UCase(sIOMode)    'Make all upper case
    
   If ((StrComp(sIOMode, "APPEND") = 0) Or (StrComp(sIOMode, "OUTPUT") = 0)) Then
        msIOMode = sIOMode
    Else
        msIOMode = "INPUT"
    End If
        
End Property

